;-------------------------- ORIGINAL: nu32.pro ---------------------------------
;
;  Plot of Poisson's ratio in X2-X3 plane of a unidirectional
;  composite material for three different fiber volume fractions.
;  Data calculated by polar.f. Ron Kriz 7-23-00 Virginia Tech
;
  pro nu32
;
; Plot and Store legend of lines for different Fiber Volume Fractions
;
  openw,2,'nu32legend.byt'
  leg=assoc(2,bytarr(180,75))
;
  openr,3,'vf.DAT' 
  readf,3,vf1,vf2,vf3
  a=intarr(5) & b=intarr(5) & c=intarr(5) & d=intarr(5)
  e=intarr(5) & f=intarr(5) & g=intarr(5)
;
  for i=1,5 do begin
    a(i-1)=20.0*i+30.0
    b(i-1)=13.0 & e(i-1)=9.0  & c(i-1)=27.0
    f(i-1)=23.0 & d(i-1)=41.0 & g(i-1)=37.0
  endfor
;
  !X.Style=4 & !Y.Style=4 & TEK_COLOR
  openzbuff,480,560
  plot,a,d,xrange=[20,460],yrange=[0,410], $
         Position=[0.0,0.0,1.0,1.0], Color=8
  oplot,a,g,Color=7
  oplot,a,c,Color=5 & oplot,a,f,Color=3
  oplot,a,b,Color=2 & oplot,a,e,Color=6
  f1=string(format='(f4.2)',vf1) & f2=string(format='(f4.2)',vf2)
  f3=string(format='(f4.2)',vf3)
  xyouts, 134, 12, '+', size=0.8 & xyouts, 134,  7, '-', size=0.8
  xyouts, 134, 26, '+', size=0.8 & xyouts, 134, 21, '-', size=0.8
  xyouts, 134, 40, '+', size=0.8 & xyouts, 134, 35, '-', size=0.8
  xyouts, 155, 10, '['+f3+']', size=1.3
  xyouts, 155, 24, '['+f2+']', size=1.3
  xyouts, 155, 38, '['+f1+']', size=1.3
  xyouts,  41, 50, 'Fiber Volume Fraction, V!Bf!N', size=1.4
  leg(0)=tvrd(40,0,180,75)
; Close z-buffer and create "jpeg" image
  closezbuff,'nu32legend.jpg'
  close,2 & close,3
;
;  Plot Poisson's Ratio, nu32, polar diagram
;
  t=fltarr(6) & tr=fltarr(5) & r=fltarr(5)
  pi=acos(-1.)
;              Read in legend
  openr,4,'nu32legend.byt'
  leg=bytarr(180,75)
  readu,4,leg
;
; Read in data and assign data to appropriate arrays
  status=DC_READ_FIXED('nu32.DAT',rows,Format='(E11.4)',/Column)
  numr=size(rows)
  numberr=numr(1)
  openr,5,'nu32.DAT'
  data=fltarr(numberr)
  datb=fltarr(numberr) & datc=fltarr(numberr) & datd=fltarr(numberr)
  date=fltarr(numberr) & datf=fltarr(numberr) & datg=fltarr(numberr)
  for i=1,numberr do begin
    readf,5,dataa,datbb,datcc,datdd,datee,datff,datgg
    data(i-1)=dataa
    datb(i-1)=datbb & datc(i-1)=datcc & datd(i-1)=datdd
    date(i-1)=datee & datf(i-1)=datff & datg(i-1)=datgg
  endfor
;
; Determine maximum radius for polar plot
  t(0)=MAX(datb) & t(1)=MAX(datc) & t(2)=MAX(datd)
  t(3)=MAX(-date) & t(4)=MAX(-datf) & t(5)=MAX(-datg) & rmax=MAX(t) & print,rmax
;
; Create five point array that forces polar plot to use equally scaled axes
  tr(0)=0.0 & tr(1)=pi/2 & tr(2)=pi & tr(3)=3*pi/2 & tr(4)=2*pi &  r(*)=rmax
;
; Set parameters for plotting into z-buffer
  TEK_COLOR
  openzbuff,480,560
  !P.Font=0 & !P.Charsize=2.0
  !X.Minor=-1 & !Y.Minor=-1 & !X.Ticks=2 & !Y.Ticks=2
  !Y.Margin=[4,4] & !X.Margin=[4,4]
  !X.Tickformat = '(f3.1)' & !Y.Tickformat = '(f3.1)'
  plot, /Polar, XSTY=8, YSTY=8, r, tr, Color=0; HIDDEN PLOT SCALES AXES SAME
  AXIS, 0, 0, XAxis = 0, XRange=[-rmax,rmax], /Save, /Data
  AXIS, 0, 0, 0, YAxis = 0, YRange=[-rmax,rmax], /Save, /Data
  XYOUTS, 55, 530, /DEVICE, 'Poissons Ratio in X!B2!N-X!B3!N Plane, Nu!B2!B3'
  XYOUTS, 255, 490, /DEVICE, 'X!B2'
  XYOUTS, 435, 295, /DEVICE, 'X!B3'
  oplot,/Polar,datd,data,Color=2 & oplot,/Polar,datg,data,Color=6
  oplot,/Polar,datc,data,Color=5 & oplot,/Polar,datf,data,Color=3
  oplot,/Polar,datb,data,Color=8 & oplot,/Polar,date,data,Color=7
  tv,leg,280,0
; Close z-buffer and create "jpeg" image
  closezbuff,'nu32.jpg'
  close,4 & close,5
;-------------------------------------------------------------------------------
  end
